@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2004 os-cillation e.K.
  *
@@ -24,7 +23,7 @@
 
 #include <exo/exo.h>
 
-G_BEGIN_DECLS;
+G_BEGIN_DECLS
 
 #define TERMINAL_TYPE_PREFERENCES             (terminal_preferences_get_type ())
 #define TERMINAL_PREFERENCES(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), TERMINAL_TYPE_PREFERENCES, TerminalPreferences))
@@ -40,7 +39,7 @@ typedef enum /*< enum,prefix=TERMINAL_SCROLLBAR >*/
 {
   TERMINAL_SCROLLBAR_NONE,
   TERMINAL_SCROLLBAR_LEFT,
-  TERMINAL_SCROLLBAR_RIGHT,
+  TERMINAL_SCROLLBAR_RIGHT
 } TerminalScrollbar;
 
 typedef enum /*< enum,prefix=TERMINAL_TITLE >*/
@@ -48,14 +47,14 @@ typedef enum /*< enum,prefix=TERMINAL_TITLE >*/
   TERMINAL_TITLE_REPLACE,
   TERMINAL_TITLE_PREPEND,
   TERMINAL_TITLE_APPEND,
-  TERMINAL_TITLE_HIDE,
+  TERMINAL_TITLE_HIDE
 } TerminalTitle;
 
 typedef enum /*< enum,prefix=TERMINAL_BACKGROUND >*/
 {
   TERMINAL_BACKGROUND_SOLID,
   TERMINAL_BACKGROUND_IMAGE,
-  TERMINAL_BACKGROUND_TRANSPARENT,
+  TERMINAL_BACKGROUND_TRANSPARENT
 } TerminalBackground;
 
 typedef enum /*< enum,prefix=TERMINAL_BACKGROUND_STYLE >*/
@@ -63,7 +62,7 @@ typedef enum /*< enum,prefix=TERMINAL_BACKGROUND_STYLE >*/
   TERMINAL_BACKGROUND_STYLE_TILED,
   TERMINAL_BACKGROUND_STYLE_CENTERED,
   TERMINAL_BACKGROUND_STYLE_SCALED,
-  TERMINAL_BACKGROUND_STYLE_STRETCHED,
+  TERMINAL_BACKGROUND_STYLE_STRETCHED
 } TerminalBackgroundStyle;
 
 typedef enum /*< enum,prefix=TERMINAL_ERASE_BINDING >*/
@@ -72,8 +71,16 @@ typedef enum /*< enum,prefix=TERMINAL_ERASE_BINDING >*/
   TERMINAL_ERASE_BINDING_ASCII_DELETE,
   TERMINAL_ERASE_BINDING_DELETE_SEQUENCE,
   TERMINAL_ERASE_BINDING_ASCII_BACKSPACE,
+  TERMINAL_ERASE_BINDING_ERASE_TTY
 } TerminalEraseBinding;
 
+typedef enum /*< enum,prefix=TERMINAL_CURSOR_SHAPE >*/
+{
+  TERMINAL_CURSOR_SHAPE_BLOCK,
+  TERMINAL_CURSOR_SHAPE_IBEAM,
+  TERMINAL_CURSOR_SHAPE_UNDERLINE
+} TerminalCursorShape;
+
 struct _TerminalPreferencesClass
 {
   GObjectClass __parent__;
@@ -83,11 +90,11 @@ GType                terminal_preferences_get_type  (void) G_GNUC_CONST;
 
 TerminalPreferences *terminal_preferences_get       (void);
 
-void                 query_color                    (TerminalPreferences *preferences,
+gboolean             terminal_preferences_get_color (TerminalPreferences *preferences,
                                                      const gchar         *property,
                                                      GdkColor            *color_return);
 
 
-G_END_DECLS;
+G_END_DECLS
 
 #endif /* !__TERMINAL_PREFERENCES_H__ */
